# user - manage igor users

This plugin is primarily a set of user interfaces to allow you to add users,
delete users and change passwords.

For adding and deleting users (and for changing passwords for anyone but yourself)
you should be logged in as *admin*.
